@@ -1,6 +1,8 @@
+//go:generate ../../../tools/readme_config_includer/generator
 package diskio
 
 import (
+	_ "embed"
 	"fmt"
 	"regexp"
 	"strings"
@@ -11,6 +13,10 @@ import (
 	"github.com/influxdata/telegraf/plugins/inputs/system"
 )
 
+// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
+//go:embed sample.conf
+var sampleConfig string
+
 var (
 	varRegex = regexp.MustCompile(`\$(?:\w+|\{\w+\})`)
 )
@@ -27,43 +33,6 @@ type DiskIO struct {
 
 	infoCache    map[string]diskInfoCache
 	deviceFilter filter.Filter
-	initialized  bool
-}
-
-func (d *DiskIO) Description() string {
-	return "Read metrics about disk IO by device"
-}
-
-var diskIOsampleConfig = `
-  ## By default, telegraf will gather stats for all devices including
-  ## disk partitions.
-  ## Setting devices will restrict the stats to the specified devices.
-  # devices = ["sda", "sdb", "vd*"]
-  ## Uncomment the following line if you need disk serial numbers.
-  # skip_serial_number = false
-  #
-  ## On systems which support it, device metadata can be added in the form of
-  ## tags.
-  ## Currently only Linux is supported via udev properties. You can view
-  ## available properties for a device by running:
-  ## 'udevadm info -q property -n /dev/sda'
-  ## Note: Most, but not all, udev properties can be accessed this way. Properties
-  ## that are currently inaccessible include DEVTYPE, DEVNAME, and DEVPATH.
-  # device_tags = ["ID_FS_TYPE", "ID_FS_USAGE"]
-  #
-  ## Using the same metadata source as device_tags, you can also customize the
-  ## name of the device via templates.
-  ## The 'name_templates' parameter is a list of templates to try and apply to
-  ## the device. The template may contain variables in the form of '$PROPERTY' or
-  ## '${PROPERTY}'. The first template which does not contain any variables not
-  ## present for the device is used as the device name tag.
-  ## The typical use case is for LVM volumes, to get the VG/LV name instead of
-  ## the near-meaningless DM-0 name.
-  # name_templates = ["$ID_FS_LABEL","$DM_VG_NAME/$DM_LV_NAME"]
-`
-
-func (d *DiskIO) SampleConfig() string {
-	return diskIOsampleConfig
 }
 
 // hasMeta reports whether s contains any special glob characters.
@@ -71,7 +40,11 @@ func hasMeta(s string) bool {
 	return strings.ContainsAny(s, "*?[")
 }
 
-func (d *DiskIO) init() error {
+func (*DiskIO) SampleConfig() string {
+	return sampleConfig
+}
+
+func (d *DiskIO) Init() error {
 	for _, device := range d.Devices {
 		if hasMeta(device) {
 			deviceFilter, err := filter.Compile(d.Devices)
@@ -81,18 +54,10 @@ func (d *DiskIO) init() error {
 			d.deviceFilter = deviceFilter
 		}
 	}
-	d.initialized = true
 	return nil
 }
 
 func (d *DiskIO) Gather(acc telegraf.Accumulator) error {
-	if !d.initialized {
-		err := d.init()
-		if err != nil {
-			return err
-		}
-	}
-
 	devices := []string{}
 	if d.deviceFilter == nil {
 		devices = d.Devices
@@ -220,4 +185,8 @@ func init() {
 	inputs.Add("diskio", func() telegraf.Input {
 		return &DiskIO{ps: ps, SkipSerialNumber: true}
 	})
+	// Backwards compatible alias
+	inputs.Add("io", func() telegraf.Input {
+		return &DiskIO{ps: ps, SkipSerialNumber: true}
+	})
 }
