@@ -26,18 +26,6 @@ type Fetcher interface {
 	Fetch(address string) ([]gohddtemp.Disk, error)
 }
 
-var hddtempSampleConfig = `
-  ## By default, telegraf gathers temps data from all disks detected by the
-  ## hddtemp.
-  ##
-  ## Only collect temps from the selected disks.
-  ##
-  ## A * as the device name will return the temperature values of all disks.
-  ##
-  # address = "127.0.0.1:7634"
-  # devices = ["sda", "*"]
-`
-
 func (*HDDTemp) SampleConfig() string {
 	return sampleConfig
 }
