@@ -9,6 +9,7 @@ import (
 	"github.com/stretchr/testify/require"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/plugins/common/kafka"
 	"github.com/influxdata/telegraf/plugins/common/tls"
 	"github.com/influxdata/telegraf/plugins/parsers/value"
@@ -42,10 +43,10 @@ type FakeCreator struct {
 	ConsumerGroup *FakeConsumerGroup
 }
 
-func (c *FakeCreator) Create(brokers []string, group string, config *sarama.Config) (ConsumerGroup, error) {
+func (c *FakeCreator) Create(brokers []string, group string, cfg *sarama.Config) (ConsumerGroup, error) {
 	c.ConsumerGroup.brokers = brokers
 	c.ConsumerGroup.group = group
-	c.ConsumerGroup.config = config
+	c.ConsumerGroup.config = cfg
 	return c.ConsumerGroup, nil
 }
 
@@ -64,6 +65,7 @@ func TestInit(t *testing.T) {
 				require.Equal(t, plugin.MaxUndeliveredMessages, defaultMaxUndeliveredMessages)
 				require.Equal(t, plugin.config.ClientID, "Telegraf")
 				require.Equal(t, plugin.config.Consumer.Offsets.Initial, sarama.OffsetOldest)
+				require.Equal(t, plugin.config.Consumer.MaxProcessingTime, 100*time.Millisecond)
 			},
 		},
 		{
@@ -165,6 +167,16 @@ func TestInit(t *testing.T) {
 				require.True(t, plugin.config.Net.TLS.Enable)
 			},
 		},
+		{
+			name: "custom max_processing_time",
+			plugin: &KafkaConsumer{
+				MaxProcessingTime: config.Duration(1000 * time.Millisecond),
+				Log:               testutil.Logger{},
+			},
+			check: func(t *testing.T, plugin *KafkaConsumer) {
+				require.Equal(t, plugin.config.Consumer.MaxProcessingTime, 1000*time.Millisecond)
+			},
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -280,8 +292,7 @@ func TestConsumerGroupHandler_Lifecycle(t *testing.T) {
 	// err = cg.ConsumeClaim(session, &claim)
 	//require.NoError(t, err)
 	// So stick with the line below for now.
-	//nolint:errcheck
-	cg.ConsumeClaim(session, &claim)
+	_ = cg.ConsumeClaim(session, &claim)
 
 	err = cg.Cleanup(session)
 	require.NoError(t, err)
