@@ -1,18 +1,24 @@
+//go:generate ../../../tools/readme_config_includer/generator
 package kafka_consumer_legacy
 
 import (
+	_ "embed"
 	"fmt"
 	"strings"
 	"sync"
 
+	"github.com/Shopify/sarama"
+	"github.com/wvanbergen/kafka/consumergroup"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/plugins/inputs"
 	"github.com/influxdata/telegraf/plugins/parsers"
-
-	"github.com/Shopify/sarama"
-	"github.com/wvanbergen/kafka/consumergroup"
 )
 
+// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
+//go:embed sample.conf
+var sampleConfig string
+
 type Kafka struct {
 	ConsumerGroup   string
 	Topics          []string
@@ -47,41 +53,10 @@ type Kafka struct {
 	doNotCommitMsgs bool
 }
 
-var sampleConfig = `
-  ## topic(s) to consume
-  topics = ["telegraf"]
-
-  ## an array of Zookeeper connection strings
-  zookeeper_peers = ["localhost:2181"]
-
-  ## Zookeeper Chroot
-  zookeeper_chroot = ""
-
-  ## the name of the consumer group
-  consumer_group = "telegraf_metrics_consumers"
-
-  ## Offset (must be either "oldest" or "newest")
-  offset = "oldest"
-
-  ## Data format to consume.
-  ## Each data format has its own unique set of configuration options, read
-  ## more about them here:
-  ## https://github.com/influxdata/telegraf/blob/master/docs/DATA_FORMATS_INPUT.md
-  data_format = "influx"
-
-  ## Maximum length of a message to consume, in bytes (default 0/unlimited);
-  ## larger messages are dropped
-  max_message_len = 65536
-`
-
-func (k *Kafka) SampleConfig() string {
+func (*Kafka) SampleConfig() string {
 	return sampleConfig
 }
 
-func (k *Kafka) Description() string {
-	return "Read metrics from Kafka topic(s)"
-}
-
 func (k *Kafka) SetParser(parser parsers.Parser) {
 	k.parser = parser
 }
