@@ -3,7 +3,7 @@ package snmp_legacy
 
 import (
 	_ "embed"
-	"log"
+	"fmt"
 	"net"
 	"os"
 	"strconv"
@@ -29,7 +29,7 @@ type Snmp struct {
 	Subtable          []Subtable
 	SnmptranslateFile string
 
-	Log telegraf.Logger
+	Log telegraf.Logger `toml:"-"`
 
 	nameToOid   map[string]string
 	initNode    Node
@@ -701,7 +701,7 @@ func (h *Host) HandleResponse(
 					acc.AddFields(fieldName, fields, tags)
 				case gosnmp.NoSuchObject, gosnmp.NoSuchInstance:
 					// Oid not found
-					log.Printf("E! [inputs.snmp_legacy] oid %q not found", oidKey)
+					acc.AddError(fmt.Errorf("oid %q not found", oidKey))
 				default:
 					// delete other data
 				}
