@@ -1,6 +1,8 @@
+//go:generate ../../../tools/readme_config_includer/generator
 package solr
 
 import (
+	_ "embed"
 	"encoding/json"
 	"fmt"
 	"math"
@@ -16,21 +18,13 @@ import (
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
+// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
+//go:embed sample.conf
+var sampleConfig string
+
 const mbeansPath = "/admin/mbeans?stats=true&wt=json&cat=CORE&cat=QUERYHANDLER&cat=UPDATEHANDLER&cat=CACHE"
 const adminCoresPath = "/solr/admin/cores?action=STATUS&wt=json"
 
-const sampleConfig = `
-  ## specify a list of one or more Solr servers
-  servers = ["http://localhost:8983"]
-
-  ## specify a list of one or more Solr cores (default - all)
-  # cores = ["main"]
-
-  ## Optional HTTP Basic Auth Credentials
-  # username = "username"
-  # password = "pa$$word"
-`
-
 // Solr is a plugin to read stats from one or many Solr servers
 type Solr struct {
 	Local       bool
@@ -126,16 +120,10 @@ func NewSolr() *Solr {
 	}
 }
 
-// SampleConfig returns sample configuration for this plugin.
-func (s *Solr) SampleConfig() string {
+func (*Solr) SampleConfig() string {
 	return sampleConfig
 }
 
-// Description returns the plugin description.
-func (s *Solr) Description() string {
-	return "Read stats from one or more Solr servers or cores"
-}
-
 // Gather reads the stats from Solr and writes it to the
 // Accumulator.
 func (s *Solr) Gather(acc telegraf.Accumulator) error {
@@ -202,7 +190,7 @@ func getCoresFromStatus(adminCoresStatus *AdminCoresStatus) []string {
 
 // Add core metrics from admin to accumulator
 // This is the only point where size_in_bytes is available (as far as I checked)
-func addAdminCoresStatusToAcc(acc telegraf.Accumulator, adminCoreStatus *AdminCoresStatus, time time.Time) {
+func addAdminCoresStatusToAcc(acc telegraf.Accumulator, adminCoreStatus *AdminCoresStatus, measurementTime time.Time) {
 	for core, metrics := range adminCoreStatus.Status {
 		coreFields := map[string]interface{}{
 			"deleted_docs":  metrics.Index.DeletedDocs,
@@ -214,13 +202,13 @@ func addAdminCoresStatusToAcc(acc telegraf.Accumulator, adminCoreStatus *AdminCo
 			"solr_admin",
 			coreFields,
 			map[string]string{"core": core},
-			time,
+			measurementTime,
 		)
 	}
 }
 
 // Add core metrics section to accumulator
-func addCoreMetricsToAcc(acc telegraf.Accumulator, core string, mBeansData *MBeansData, time time.Time) error {
+func addCoreMetricsToAcc(acc telegraf.Accumulator, core string, mBeansData *MBeansData, measurementTime time.Time) error {
 	var coreMetrics map[string]Core
 	if len(mBeansData.SolrMbeans) < 2 {
 		return fmt.Errorf("no core metric data to unmarshal")
@@ -243,14 +231,14 @@ func addCoreMetricsToAcc(acc telegraf.Accumulator, core string, mBeansData *MBea
 			map[string]string{
 				"core":    core,
 				"handler": name},
-			time,
+			measurementTime,
 		)
 	}
 	return nil
 }
 
 // Add query metrics section to accumulator
-func addQueryHandlerMetricsToAcc(acc telegraf.Accumulator, core string, mBeansData *MBeansData, time time.Time) error {
+func addQueryHandlerMetricsToAcc(acc telegraf.Accumulator, core string, mBeansData *MBeansData, measurementTime time.Time) error {
 	var queryMetrics map[string]QueryHandler
 
 	if len(mBeansData.SolrMbeans) < 4 {
@@ -284,7 +272,7 @@ func addQueryHandlerMetricsToAcc(acc telegraf.Accumulator, core string, mBeansDa
 			map[string]string{
 				"core":    core,
 				"handler": name},
-			time,
+			measurementTime,
 		)
 	}
 	return nil
@@ -324,7 +312,7 @@ func convertQueryHandlerMap(value map[string]interface{}) map[string]interface{}
 }
 
 // Add update metrics section to accumulator
-func addUpdateHandlerMetricsToAcc(acc telegraf.Accumulator, core string, mBeansData *MBeansData, time time.Time) error {
+func addUpdateHandlerMetricsToAcc(acc telegraf.Accumulator, core string, mBeansData *MBeansData, measurementTime time.Time) error {
 	var updateMetrics map[string]UpdateHandler
 
 	if len(mBeansData.SolrMbeans) < 6 {
@@ -363,7 +351,7 @@ func addUpdateHandlerMetricsToAcc(acc telegraf.Accumulator, core string, mBeansD
 			map[string]string{
 				"core":    core,
 				"handler": name},
-			time,
+			measurementTime,
 		)
 	}
 	return nil
@@ -404,7 +392,7 @@ func getInt(unk interface{}) int64 {
 }
 
 // Add cache metrics section to accumulator
-func addCacheMetricsToAcc(acc telegraf.Accumulator, core string, mBeansData *MBeansData, time time.Time) error {
+func addCacheMetricsToAcc(acc telegraf.Accumulator, core string, mBeansData *MBeansData, measurementTime time.Time) error {
 	if len(mBeansData.SolrMbeans) < 8 {
 		return fmt.Errorf("no cache metric data to unmarshal")
 	}
@@ -444,7 +432,7 @@ func addCacheMetricsToAcc(acc telegraf.Accumulator, core string, mBeansData *MBe
 			map[string]string{
 				"core":    core,
 				"handler": name},
-			time,
+			measurementTime,
 		)
 	}
 	return nil
