@@ -4,7 +4,6 @@ package kafka
 import (
 	_ "embed"
 	"fmt"
-	"log"
 	"strings"
 	"time"
 
@@ -68,22 +67,21 @@ type TopicSuffix struct {
 
 // DebugLogger logs messages from sarama at the debug level.
 type DebugLogger struct {
+	Log telegraf.Logger
 }
 
-func (*DebugLogger) Print(v ...interface{}) {
+func (l *DebugLogger) Print(v ...interface{}) {
 	args := make([]interface{}, 0, len(v)+1)
-	args = append(append(args, "D! [sarama] "), v...)
-	log.Print(args...)
+	args = append(append(args, "[sarama] "), v...)
+	l.Log.Debug(args...)
 }
 
-func (*DebugLogger) Printf(format string, v ...interface{}) {
-	log.Printf("D! [sarama] "+format, v...)
+func (l *DebugLogger) Printf(format string, v ...interface{}) {
+	l.Log.Debugf("[sarama] "+format, v...)
 }
 
-func (*DebugLogger) Println(v ...interface{}) {
-	args := make([]interface{}, 0, len(v)+1)
-	args = append(append(args, "D! [sarama] "), v...)
-	log.Println(args...)
+func (l *DebugLogger) Println(v ...interface{}) {
+	l.Print(v)
 }
 
 func ValidateTopicSuffixMethod(method string) error {
@@ -140,6 +138,8 @@ func (k *Kafka) SetSerializer(serializer serializers.Serializer) {
 }
 
 func (k *Kafka) Init() error {
+	sarama.Logger = &DebugLogger{Log: k.Log}
+
 	err := ValidateTopicSuffixMethod(k.TopicSuffix.Method)
 	if err != nil {
 		return err
@@ -259,7 +259,6 @@ func (k *Kafka) Write(metrics []telegraf.Metric) error {
 }
 
 func init() {
-	sarama.Logger = &DebugLogger{}
 	outputs.Add("kafka", func() telegraf.Output {
 		return &Kafka{
 			WriteConfig: kafka.WriteConfig{
