@@ -1,8 +1,9 @@
+//go:generate ../../../tools/readme_config_includer/generator
 package newrelic
 
-// newrelic.go
 import (
 	"context"
+	_ "embed"
 	"fmt"
 	"net/http"
 	"net/url"
@@ -16,6 +17,10 @@ import (
 	"github.com/influxdata/telegraf/plugins/outputs"
 )
 
+// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
+//go:embed sample.conf
+var sampleConfig string
+
 // NewRelic nr structure
 type NewRelic struct {
 	InsightsKey  string          `toml:"insights_key"`
@@ -31,35 +36,8 @@ type NewRelic struct {
 	client      http.Client
 }
 
-// Description returns a one-sentence description on the Output
-func (nr *NewRelic) Description() string {
-	return "Send metrics to New Relic metrics endpoint"
-}
-
-// SampleConfig : return  default configuration of the Output
-func (nr *NewRelic) SampleConfig() string {
-	return `
-  ## The 'insights_key' parameter requires a NR license key.
-  ## New Relic recommends you create one
-  ## with a convenient name such as TELEGRAF_INSERT_KEY.
-  ## reference: https://docs.newrelic.com/docs/apis/intro-apis/new-relic-api-keys/#ingest-license-key
-  # insights_key = "New Relic License Key Here"
-
-  ## Prefix to add to add to metric name for easy identification.
-  ## This is very useful if your metric names are ambiguous.
-  # metric_prefix = ""
-
-  ## Timeout for writes to the New Relic API.
-  # timeout = "15s"
-
-  ## HTTP Proxy override. If unset use values from the standard
-  ## proxy environment variables to determine proxy, if any.
-  # http_proxy = "http://corporate.proxy:3128"
-
-  ## Metric URL override to enable geographic location endpoints.
-  # If not set use values from the standard 
-  # metric_url = "https://metric-api.newrelic.com/metric/v1"
-`
+func (*NewRelic) SampleConfig() string {
+	return sampleConfig
 }
 
 // Connect to the Output
