@@ -13,11 +13,11 @@ import (
 	"github.com/aws/aws-sdk-go-v2/aws"
 	"github.com/aws/aws-sdk-go-v2/service/timestreamwrite"
 	"github.com/aws/aws-sdk-go-v2/service/timestreamwrite/types"
+	"github.com/stretchr/testify/require"
+
 	"github.com/influxdata/telegraf"
 	internalaws "github.com/influxdata/telegraf/config/aws"
 	"github.com/influxdata/telegraf/testutil"
-
-	"github.com/stretchr/testify/assert"
 )
 
 const tsDbName = "testDb"
@@ -28,6 +28,7 @@ const testSingleTableDim = "namespace"
 var time1 = time.Date(2009, time.November, 10, 22, 0, 0, 0, time.UTC)
 
 const time1Epoch = "1257890400"
+const timeUnit = types.TimeUnitSeconds
 
 var time2 = time.Date(2009, time.November, 10, 23, 0, 0, 0, time.UTC)
 
@@ -49,26 +50,25 @@ func (m *mockTimestreamClient) DescribeDatabase(context.Context, *timestreamwrit
 }
 
 func TestConnectValidatesConfigParameters(t *testing.T) {
-	assertions := assert.New(t)
 	WriteFactory = func(credentialConfig *internalaws.CredentialConfig) (WriteClient, error) {
 		return &mockTimestreamClient{}, nil
 	}
 	// checking base arguments
 	noDatabaseName := Timestream{Log: testutil.Logger{}}
-	assertions.Contains(noDatabaseName.Connect().Error(), "DatabaseName")
+	require.Contains(t, noDatabaseName.Connect().Error(), "DatabaseName")
 
 	noMappingMode := Timestream{
 		DatabaseName: tsDbName,
 		Log:          testutil.Logger{},
 	}
-	assertions.Contains(noMappingMode.Connect().Error(), "MappingMode")
+	require.Contains(t, noMappingMode.Connect().Error(), "MappingMode")
 
 	incorrectMappingMode := Timestream{
 		DatabaseName: tsDbName,
 		MappingMode:  "foo",
 		Log:          testutil.Logger{},
 	}
-	assertions.Contains(incorrectMappingMode.Connect().Error(), "single-table")
+	require.Contains(t, incorrectMappingMode.Connect().Error(), "single-table")
 
 	// multi-table arguments
 	validMappingModeMultiTable := Timestream{
@@ -76,7 +76,7 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		MappingMode:  MappingModeMultiTable,
 		Log:          testutil.Logger{},
 	}
-	assertions.Nil(validMappingModeMultiTable.Connect())
+	require.Nil(t, validMappingModeMultiTable.Connect())
 
 	singleTableNameWithMultiTable := Timestream{
 		DatabaseName:    tsDbName,
@@ -84,7 +84,7 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		SingleTableName: testSingleTableName,
 		Log:             testutil.Logger{},
 	}
-	assertions.Contains(singleTableNameWithMultiTable.Connect().Error(), "SingleTableName")
+	require.Contains(t, singleTableNameWithMultiTable.Connect().Error(), "SingleTableName")
 
 	singleTableDimensionWithMultiTable := Timestream{
 		DatabaseName: tsDbName,
@@ -92,7 +92,7 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		SingleTableDimensionNameForTelegrafMeasurementName: testSingleTableDim,
 		Log: testutil.Logger{},
 	}
-	assertions.Contains(singleTableDimensionWithMultiTable.Connect().Error(),
+	require.Contains(t, singleTableDimensionWithMultiTable.Connect().Error(),
 		"SingleTableDimensionNameForTelegrafMeasurementName")
 
 	// single-table arguments
@@ -101,7 +101,7 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		MappingMode:  MappingModeSingleTable,
 		Log:          testutil.Logger{},
 	}
-	assertions.Contains(noTableNameMappingModeSingleTable.Connect().Error(), "SingleTableName")
+	require.Contains(t, noTableNameMappingModeSingleTable.Connect().Error(), "SingleTableName")
 
 	noDimensionNameMappingModeSingleTable := Timestream{
 		DatabaseName:    tsDbName,
@@ -109,7 +109,7 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		SingleTableName: testSingleTableName,
 		Log:             testutil.Logger{},
 	}
-	assertions.Contains(noDimensionNameMappingModeSingleTable.Connect().Error(),
+	require.Contains(t, noDimensionNameMappingModeSingleTable.Connect().Error(),
 		"SingleTableDimensionNameForTelegrafMeasurementName")
 
 	validConfigurationMappingModeSingleTable := Timestream{
@@ -119,7 +119,7 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		SingleTableDimensionNameForTelegrafMeasurementName: testSingleTableDim,
 		Log: testutil.Logger{},
 	}
-	assertions.Nil(validConfigurationMappingModeSingleTable.Connect())
+	require.Nil(t, validConfigurationMappingModeSingleTable.Connect())
 
 	// create table arguments
 	createTableNoMagneticRetention := Timestream{
@@ -128,7 +128,7 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		CreateTableIfNotExists: true,
 		Log:                    testutil.Logger{},
 	}
-	assertions.Contains(createTableNoMagneticRetention.Connect().Error(),
+	require.Contains(t, createTableNoMagneticRetention.Connect().Error(),
 		"CreateTableMagneticStoreRetentionPeriodInDays")
 
 	createTableNoMemoryRetention := Timestream{
@@ -138,7 +138,7 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		CreateTableMagneticStoreRetentionPeriodInDays: 3,
 		Log: testutil.Logger{},
 	}
-	assertions.Contains(createTableNoMemoryRetention.Connect().Error(),
+	require.Contains(t, createTableNoMemoryRetention.Connect().Error(),
 		"CreateTableMemoryStoreRetentionPeriodInHours")
 
 	createTableValid := Timestream{
@@ -149,7 +149,7 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		CreateTableMemoryStoreRetentionPeriodInHours:  3,
 		Log: testutil.Logger{},
 	}
-	assertions.Nil(createTableValid.Connect())
+	require.Nil(t, createTableValid.Connect())
 
 	// describe table on start arguments
 	describeTableInvoked := Timestream{
@@ -158,7 +158,7 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		DescribeDatabaseOnStart: true,
 		Log:                     testutil.Logger{},
 	}
-	assertions.Contains(describeTableInvoked.Connect().Error(), "hello from DescribeDatabase")
+	require.Contains(t, describeTableInvoked.Connect().Error(), "hello from DescribeDatabase")
 }
 
 type mockTimestreamErrorClient struct {
@@ -176,7 +176,6 @@ func (m *mockTimestreamErrorClient) DescribeDatabase(context.Context, *timestrea
 }
 
 func TestThrottlingErrorIsReturnedToTelegraf(t *testing.T) {
-	assertions := assert.New(t)
 	WriteFactory = func(credentialConfig *internalaws.CredentialConfig) (WriteClient, error) {
 		return &mockTimestreamErrorClient{
 			ErrorToReturnOnWriteRecords: &types.ThrottlingException{Message: aws.String("Throttling Test")},
@@ -188,7 +187,7 @@ func TestThrottlingErrorIsReturnedToTelegraf(t *testing.T) {
 		DatabaseName: tsDbName,
 		Log:          testutil.Logger{},
 	}
-	assertions.NoError(plugin.Connect())
+	require.NoError(t, plugin.Connect())
 	input := testutil.MustMetric(
 		metricName1,
 		map[string]string{"tag1": "value1"},
@@ -198,12 +197,11 @@ func TestThrottlingErrorIsReturnedToTelegraf(t *testing.T) {
 
 	err := plugin.Write([]telegraf.Metric{input})
 
-	assertions.NotNil(err, "Expected an error to be returned to Telegraf, "+
+	require.NotNil(t, err, "Expected an error to be returned to Telegraf, "+
 		"so that the write will be retried by Telegraf later.")
 }
 
 func TestRejectedRecordsErrorResultsInMetricsBeingSkipped(t *testing.T) {
-	assertions := assert.New(t)
 	WriteFactory = func(credentialConfig *internalaws.CredentialConfig) (WriteClient, error) {
 		return &mockTimestreamErrorClient{
 			ErrorToReturnOnWriteRecords: &types.RejectedRecordsException{Message: aws.String("RejectedRecords Test")},
@@ -215,7 +213,7 @@ func TestRejectedRecordsErrorResultsInMetricsBeingSkipped(t *testing.T) {
 		DatabaseName: tsDbName,
 		Log:          testutil.Logger{},
 	}
-	assertions.NoError(plugin.Connect())
+	require.NoError(t, plugin.Connect())
 	input := testutil.MustMetric(
 		metricName1,
 		map[string]string{"tag1": "value1"},
@@ -225,7 +223,7 @@ func TestRejectedRecordsErrorResultsInMetricsBeingSkipped(t *testing.T) {
 
 	err := plugin.Write([]telegraf.Metric{input})
 
-	assertions.Nil(err, "Expected to silently swallow the RejectedRecordsException, "+
+	require.Nil(t, err, "Expected to silently swallow the RejectedRecordsException, "+
 		"as retrying this error doesn't make sense.")
 }
 
@@ -253,37 +251,58 @@ func TestTransformMetricsSkipEmptyMetric(t *testing.T) {
 		time1,
 	)
 
-	expectedResult1SingleTable := buildExpectedRecords(SimpleInput{
-		t:             time1Epoch,
-		tableName:     testSingleTableName,
-		dimensions:    map[string]string{"tag2": "value2", testSingleTableDim: metricName1},
-		measureValues: map[string]string{"value": "10"},
-	})
-	expectedResult2SingleTable := buildExpectedRecords(SimpleInput{
-		t:             time1Epoch,
-		tableName:     testSingleTableName,
-		dimensions:    map[string]string{testSingleTableDim: metricName1},
-		measureValues: map[string]string{"value": "20"},
+	records := buildRecords([]SimpleInput{
+		{
+			t:             time1Epoch,
+			tableName:     metricName1,
+			dimensions:    map[string]string{"tag2": "value2", testSingleTableDim: metricName1},
+			measureValues: map[string]string{"value": "10"},
+		},
+
+		{
+			t:             time1Epoch,
+			tableName:     metricName1,
+			dimensions:    map[string]string{testSingleTableDim: metricName1},
+			measureValues: map[string]string{"value": "20"},
+		},
 	})
+
+	expectedResultSingleTable := &timestreamwrite.WriteRecordsInput{
+		DatabaseName:     aws.String(tsDbName),
+		TableName:        aws.String(testSingleTableName),
+		Records:          records,
+		CommonAttributes: &types.Record{},
+	}
+
 	comparisonTest(t, MappingModeSingleTable,
 		[]telegraf.Metric{input1, input2, input3},
-		[]*timestreamwrite.WriteRecordsInput{expectedResult1SingleTable, expectedResult2SingleTable})
+		[]*timestreamwrite.WriteRecordsInput{expectedResultSingleTable})
 
-	expectedResult1MultiTable := buildExpectedRecords(SimpleInput{
-		t:             time1Epoch,
-		tableName:     metricName1,
-		dimensions:    map[string]string{"tag2": "value2"},
-		measureValues: map[string]string{"value": "10"},
-	})
-	expectedResult2MultiTable := buildExpectedRecords(SimpleInput{
-		t:             time1Epoch,
-		tableName:     metricName1,
-		dimensions:    map[string]string{},
-		measureValues: map[string]string{"value": "20"},
+	recordsMulti := buildRecords([]SimpleInput{
+		{
+			t:             time1Epoch,
+			tableName:     metricName1,
+			dimensions:    map[string]string{"tag2": "value2"},
+			measureValues: map[string]string{"value": "10"},
+		},
+		{
+			t:             time1Epoch,
+			tableName:     metricName1,
+			dimensions:    map[string]string{},
+			measureValues: map[string]string{"value": "20"},
+		},
 	})
+
+	expectedResultMultiTable := &timestreamwrite.WriteRecordsInput{
+		DatabaseName:     aws.String(tsDbName),
+		TableName:        aws.String(metricName1),
+		Records:          recordsMulti,
+		CommonAttributes: &types.Record{},
+	}
+
 	comparisonTest(t, MappingModeMultiTable,
 		[]telegraf.Metric{input1, input2, input3},
-		[]*timestreamwrite.WriteRecordsInput{expectedResult1MultiTable, expectedResult2MultiTable})
+		[]*timestreamwrite.WriteRecordsInput{expectedResultMultiTable})
 }
 
 func TestTransformMetricsRequestsAboveLimitAreSplit(t *testing.T) {
@@ -308,13 +327,13 @@ func TestTransformMetricsRequestsAboveLimitAreSplit(t *testing.T) {
 		resultFields[fieldName] = "10"
 	}
 
-	expectedResult1SingleTable := buildExpectedRecords(SimpleInput{
+	expectedResult1SingleTable := buildExpectedInput(SimpleInput{
 		t:             time1Epoch,
 		tableName:     testSingleTableName,
 		dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName1},
 		measureValues: resultFields,
 	})
-	expectedResult2SingleTable := buildExpectedRecords(SimpleInput{
+	expectedResult2SingleTable := buildExpectedInput(SimpleInput{
 		t:             time1Epoch,
 		tableName:     testSingleTableName,
 		dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName1},
@@ -324,13 +343,13 @@ func TestTransformMetricsRequestsAboveLimitAreSplit(t *testing.T) {
 		inputs,
 		[]*timestreamwrite.WriteRecordsInput{expectedResult1SingleTable, expectedResult2SingleTable})
 
-	expectedResult1MultiTable := buildExpectedRecords(SimpleInput{
+	expectedResult1MultiTable := buildExpectedInput(SimpleInput{
 		t:             time1Epoch,
 		tableName:     metricName1,
 		dimensions:    map[string]string{"tag1": "value1"},
 		measureValues: resultFields,
 	})
-	expectedResult2MultiTable := buildExpectedRecords(SimpleInput{
+	expectedResult2MultiTable := buildExpectedInput(SimpleInput{
 		t:             time1Epoch,
 		tableName:     metricName1,
 		dimensions:    map[string]string{"tag1": "value1"},
@@ -350,8 +369,9 @@ func TestTransformMetricsDifferentDimensionsSameTimestampsAreWrittenSeparate(t *
 		},
 		time1,
 	)
+
 	input2 := testutil.MustMetric(
-		metricName1,
+		metricName2,
 		map[string]string{"tag2": "value2"},
 		map[string]interface{}{
 			"value_supported3": float64(30),
@@ -359,32 +379,42 @@ func TestTransformMetricsDifferentDimensionsSameTimestampsAreWrittenSeparate(t *
 		time1,
 	)
 
-	expectedResult1SingleTable := buildExpectedRecords(SimpleInput{
-		t:             time1Epoch,
-		tableName:     testSingleTableName,
-		dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName1},
-		measureValues: map[string]string{"value_supported1": "10", "value_supported2": "20"},
-	})
-	expectedResult2SingleTable := buildExpectedRecords(SimpleInput{
-		t:             time1Epoch,
-		tableName:     testSingleTableName,
-		dimensions:    map[string]string{"tag2": "value2", testSingleTableDim: metricName1},
-		measureValues: map[string]string{"value_supported3": "30"},
+	recordsSingle := buildRecords([]SimpleInput{
+		{
+			t:             time1Epoch,
+			tableName:     testSingleTableName,
+			dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName1},
+			measureValues: map[string]string{"value_supported1": "10", "value_supported2": "20"},
+		},
+		{
+			t:             time1Epoch,
+			tableName:     testSingleTableName,
+			dimensions:    map[string]string{"tag2": "value2", testSingleTableDim: metricName2},
+			measureValues: map[string]string{"value_supported3": "30"},
+		},
 	})
 
+	expectedResultSingleTable := &timestreamwrite.WriteRecordsInput{
+		DatabaseName:     aws.String(tsDbName),
+		TableName:        aws.String(testSingleTableName),
+		Records:          recordsSingle,
+		CommonAttributes: &types.Record{},
+	}
+
 	comparisonTest(t, MappingModeSingleTable,
 		[]telegraf.Metric{input1, input2},
-		[]*timestreamwrite.WriteRecordsInput{expectedResult1SingleTable, expectedResult2SingleTable})
+		[]*timestreamwrite.WriteRecordsInput{expectedResultSingleTable})
 
-	expectedResult1MultiTable := buildExpectedRecords(SimpleInput{
+	expectedResult1MultiTable := buildExpectedInput(SimpleInput{
 		t:             time1Epoch,
 		tableName:     metricName1,
 		dimensions:    map[string]string{"tag1": "value1"},
 		measureValues: map[string]string{"value_supported1": "10", "value_supported2": "20"},
 	})
-	expectedResult2MultiTable := buildExpectedRecords(SimpleInput{
+
+	expectedResult2MultiTable := buildExpectedInput(SimpleInput{
 		t:             time1Epoch,
-		tableName:     metricName1,
+		tableName:     metricName2,
 		dimensions:    map[string]string{"tag2": "value2"},
 		measureValues: map[string]string{"value_supported3": "30"},
 	})
@@ -404,7 +434,7 @@ func TestTransformMetricsSameDimensionsDifferentDimensionValuesAreWrittenSeparat
 		time1,
 	)
 	input2 := testutil.MustMetric(
-		metricName1,
+		metricName2,
 		map[string]string{"tag1": "value2"},
 		map[string]interface{}{
 			"value_supported1": float64(20),
@@ -412,32 +442,41 @@ func TestTransformMetricsSameDimensionsDifferentDimensionValuesAreWrittenSeparat
 		time1,
 	)
 
-	expectedResult1SingleTable := buildExpectedRecords(SimpleInput{
-		t:             time1Epoch,
-		tableName:     testSingleTableName,
-		dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName1},
-		measureValues: map[string]string{"value_supported1": "10"},
-	})
-	expectedResult2SingleTable := buildExpectedRecords(SimpleInput{
-		t:             time1Epoch,
-		tableName:     testSingleTableName,
-		dimensions:    map[string]string{"tag1": "value2", testSingleTableDim: metricName1},
-		measureValues: map[string]string{"value_supported1": "20"},
+	recordsSingle := buildRecords([]SimpleInput{
+		{
+			t:             time1Epoch,
+			tableName:     testSingleTableName,
+			dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName1},
+			measureValues: map[string]string{"value_supported1": "10"},
+		},
+		{
+			t:             time1Epoch,
+			tableName:     testSingleTableName,
+			dimensions:    map[string]string{"tag1": "value2", testSingleTableDim: metricName2},
+			measureValues: map[string]string{"value_supported1": "20"},
+		},
 	})
 
+	expectedResultSingleTable := &timestreamwrite.WriteRecordsInput{
+		DatabaseName:     aws.String(tsDbName),
+		TableName:        aws.String(testSingleTableName),
+		Records:          recordsSingle,
+		CommonAttributes: &types.Record{},
+	}
+
 	comparisonTest(t, MappingModeSingleTable,
 		[]telegraf.Metric{input1, input2},
-		[]*timestreamwrite.WriteRecordsInput{expectedResult1SingleTable, expectedResult2SingleTable})
+		[]*timestreamwrite.WriteRecordsInput{expectedResultSingleTable})
 
-	expectedResult1MultiTable := buildExpectedRecords(SimpleInput{
+	expectedResult1MultiTable := buildExpectedInput(SimpleInput{
 		t:             time1Epoch,
 		tableName:     metricName1,
 		dimensions:    map[string]string{"tag1": "value1"},
 		measureValues: map[string]string{"value_supported1": "10"},
 	})
-	expectedResult2MultiTable := buildExpectedRecords(SimpleInput{
+	expectedResult2MultiTable := buildExpectedInput(SimpleInput{
 		t:             time1Epoch,
-		tableName:     metricName1,
+		tableName:     metricName2,
 		dimensions:    map[string]string{"tag1": "value2"},
 		measureValues: map[string]string{"value_supported1": "20"},
 	})
@@ -465,39 +504,57 @@ func TestTransformMetricsSameDimensionsDifferentTimestampsAreWrittenSeparate(t *
 		time2,
 	)
 
-	expectedResult1SingleTable := buildExpectedRecords(SimpleInput{
-		t:             time1Epoch,
-		tableName:     testSingleTableName,
-		dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName1},
-		measureValues: map[string]string{"value_supported1": "10", "value_supported2": "20"},
-	})
-	expectedResult2SingleTable := buildExpectedRecords(SimpleInput{
-		t:             time2Epoch,
-		tableName:     testSingleTableName,
-		dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName1},
-		measureValues: map[string]string{"value_supported3": "30"},
+	recordsSingle := buildRecords([]SimpleInput{
+		{
+			t:             time1Epoch,
+			tableName:     testSingleTableName,
+			dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName1},
+			measureValues: map[string]string{"value_supported1": "10", "value_supported2": "20"},
+		},
+		{
+			t:             time2Epoch,
+			tableName:     testSingleTableName,
+			dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName1},
+			measureValues: map[string]string{"value_supported3": "30"},
+		},
 	})
 
+	expectedResultSingleTable := &timestreamwrite.WriteRecordsInput{
+		DatabaseName:     aws.String(tsDbName),
+		TableName:        aws.String(testSingleTableName),
+		Records:          recordsSingle,
+		CommonAttributes: &types.Record{},
+	}
+
 	comparisonTest(t, MappingModeSingleTable,
 		[]telegraf.Metric{input1, input2},
-		[]*timestreamwrite.WriteRecordsInput{expectedResult1SingleTable, expectedResult2SingleTable})
+		[]*timestreamwrite.WriteRecordsInput{expectedResultSingleTable})
 
-	expectedResult1MultiTable := buildExpectedRecords(SimpleInput{
-		t:             time1Epoch,
-		tableName:     metricName1,
-		dimensions:    map[string]string{"tag1": "value1"},
-		measureValues: map[string]string{"value_supported1": "10", "value_supported2": "20"},
-	})
-	expectedResult2MultiTable := buildExpectedRecords(SimpleInput{
-		t:             time2Epoch,
-		tableName:     metricName1,
-		dimensions:    map[string]string{"tag1": "value1"},
-		measureValues: map[string]string{"value_supported3": "30"},
+	recordsMultiTable := buildRecords([]SimpleInput{
+		{
+			t:             time1Epoch,
+			tableName:     metricName1,
+			dimensions:    map[string]string{"tag1": "value1"},
+			measureValues: map[string]string{"value_supported1": "10", "value_supported2": "20"},
+		},
+		{
+			t:             time2Epoch,
+			tableName:     metricName1,
+			dimensions:    map[string]string{"tag1": "value1"},
+			measureValues: map[string]string{"value_supported3": "30"},
+		},
 	})
 
+	expectedResultMultiTable := &timestreamwrite.WriteRecordsInput{
+		DatabaseName:     aws.String(tsDbName),
+		TableName:        aws.String(metricName1),
+		Records:          recordsMultiTable,
+		CommonAttributes: &types.Record{},
+	}
+
 	comparisonTest(t, MappingModeMultiTable,
 		[]telegraf.Metric{input1, input2},
-		[]*timestreamwrite.WriteRecordsInput{expectedResult1MultiTable, expectedResult2MultiTable})
+		[]*timestreamwrite.WriteRecordsInput{expectedResultMultiTable})
 }
 
 func TestTransformMetricsSameDimensionsSameTimestampsAreWrittenTogether(t *testing.T) {
@@ -518,7 +575,7 @@ func TestTransformMetricsSameDimensionsSameTimestampsAreWrittenTogether(t *testi
 		time1,
 	)
 
-	expectedResultSingleTable := buildExpectedRecords(SimpleInput{
+	expectedResultSingleTable := buildExpectedInput(SimpleInput{
 		t:             time1Epoch,
 		tableName:     testSingleTableName,
 		dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName1},
@@ -529,7 +586,7 @@ func TestTransformMetricsSameDimensionsSameTimestampsAreWrittenTogether(t *testi
 		[]telegraf.Metric{input1, input2},
 		[]*timestreamwrite.WriteRecordsInput{expectedResultSingleTable})
 
-	expectedResultMultiTable := buildExpectedRecords(SimpleInput{
+	expectedResultMultiTable := buildExpectedInput(SimpleInput{
 		t:             time1Epoch,
 		tableName:     metricName1,
 		dimensions:    map[string]string{"tag1": "value1"},
@@ -559,30 +616,39 @@ func TestTransformMetricsDifferentMetricsAreWrittenToDifferentTablesInMultiTable
 		time1,
 	)
 
-	expectedResult1SingleTable := buildExpectedRecords(SimpleInput{
-		t:             time1Epoch,
-		tableName:     testSingleTableName,
-		dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName1},
-		measureValues: map[string]string{"value_supported1": "10", "value_supported2": "20"},
-	})
-	expectedResult2SingleTable := buildExpectedRecords(SimpleInput{
-		t:             time1Epoch,
-		tableName:     testSingleTableName,
-		dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName2},
-		measureValues: map[string]string{"value_supported3": "30"},
+	recordsSingle := buildRecords([]SimpleInput{
+		{
+			t:             time1Epoch,
+			tableName:     testSingleTableName,
+			dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName1},
+			measureValues: map[string]string{"value_supported1": "10", "value_supported2": "20"},
+		},
+		{
+			t:             time1Epoch,
+			tableName:     testSingleTableName,
+			dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName2},
+			measureValues: map[string]string{"value_supported3": "30"},
+		},
 	})
 
+	expectedResultSingleTable := &timestreamwrite.WriteRecordsInput{
+		DatabaseName:     aws.String(tsDbName),
+		TableName:        aws.String(testSingleTableName),
+		Records:          recordsSingle,
+		CommonAttributes: &types.Record{},
+	}
+
 	comparisonTest(t, MappingModeSingleTable,
 		[]telegraf.Metric{input1, input2},
-		[]*timestreamwrite.WriteRecordsInput{expectedResult1SingleTable, expectedResult2SingleTable})
+		[]*timestreamwrite.WriteRecordsInput{expectedResultSingleTable})
 
-	expectedResult1MultiTable := buildExpectedRecords(SimpleInput{
+	expectedResult1MultiTable := buildExpectedInput(SimpleInput{
 		t:             time1Epoch,
 		tableName:     metricName1,
 		dimensions:    map[string]string{"tag1": "value1"},
 		measureValues: map[string]string{"value_supported1": "10", "value_supported2": "20"},
 	})
-	expectedResult2MultiTable := buildExpectedRecords(SimpleInput{
+	expectedResult2MultiTable := buildExpectedInput(SimpleInput{
 		t:             time1Epoch,
 		tableName:     metricName2,
 		dimensions:    map[string]string{"tag1": "value1"},
@@ -603,7 +669,7 @@ func TestTransformMetricsUnsupportedFieldsAreSkipped(t *testing.T) {
 		},
 		time1,
 	)
-	expectedResultSingleTable := buildExpectedRecords(SimpleInput{
+	expectedResultSingleTable := buildExpectedInput(SimpleInput{
 		t:             time1Epoch,
 		tableName:     testSingleTableName,
 		dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName1},
@@ -614,7 +680,7 @@ func TestTransformMetricsUnsupportedFieldsAreSkipped(t *testing.T) {
 		[]telegraf.Metric{metricWithUnsupportedField},
 		[]*timestreamwrite.WriteRecordsInput{expectedResultSingleTable})
 
-	expectedResultMultiTable := buildExpectedRecords(SimpleInput{
+	expectedResultMultiTable := buildExpectedInput(SimpleInput{
 		t:             time1Epoch,
 		tableName:     metricName1,
 		dimensions:    map[string]string{"tag1": "value1"},
@@ -626,6 +692,22 @@ func TestTransformMetricsUnsupportedFieldsAreSkipped(t *testing.T) {
 		[]*timestreamwrite.WriteRecordsInput{expectedResultMultiTable})
 }
 
+func TestCustomEndpoint(t *testing.T) {
+	customEndpoint := "http://test.custom.endpoint.com"
+	plugin := Timestream{
+		MappingMode:      MappingModeMultiTable,
+		DatabaseName:     tsDbName,
+		Log:              testutil.Logger{},
+		CredentialConfig: internalaws.CredentialConfig{EndpointURL: customEndpoint},
+	}
+
+	// validate config correctness
+	err := plugin.Connect()
+	require.Nil(t, err, "Invalid configuration")
+	// Check customURL is used
+	require.Equal(t, plugin.EndpointURL, customEndpoint)
+}
+
 func comparisonTest(t *testing.T,
 	mappingMode string,
 	telegrafMetrics []telegraf.Metric,
@@ -649,13 +731,20 @@ func comparisonTest(t *testing.T,
 			Log:          testutil.Logger{},
 		}
 	}
-	assertions := assert.New(t)
 
+	comparison(t, plugin, mappingMode, telegrafMetrics, timestreamRecords)
+}
+
+func comparison(t *testing.T,
+	plugin Timestream,
+	mappingMode string,
+	telegrafMetrics []telegraf.Metric,
+	timestreamRecords []*timestreamwrite.WriteRecordsInput) {
 	result := plugin.TransformMetrics(telegrafMetrics)
 
-	assertions.Equal(len(timestreamRecords), len(result), "The number of transformed records was expected to be different")
+	require.Equal(t, len(timestreamRecords), len(result), "The number of transformed records was expected to be different")
 	for _, tsRecord := range timestreamRecords {
-		assertions.True(arrayContains(result, tsRecord), "Expected that the list of requests to Timestream: \n%s\n\n "+
+		require.True(t, arrayContains(result, tsRecord), "Expected that the list of requests to Timestream: \n%s\n\n "+
 			"will contain request: \n%s\n\nUsed MappingMode: %s", result, tsRecord, mappingMode)
 	}
 }
@@ -703,7 +792,7 @@ type SimpleInput struct {
 	measureValues map[string]string
 }
 
-func buildExpectedRecords(i SimpleInput) *timestreamwrite.WriteRecordsInput {
+func buildExpectedInput(i SimpleInput) *timestreamwrite.WriteRecordsInput {
 	var tsDimensions []types.Dimension
 	for k, v := range i.dimensions {
 		tsDimensions = append(tsDimensions, types.Dimension{
@@ -718,19 +807,54 @@ func buildExpectedRecords(i SimpleInput) *timestreamwrite.WriteRecordsInput {
 			MeasureName:      aws.String(k),
 			MeasureValue:     aws.String(v),
 			MeasureValueType: types.MeasureValueTypeDouble,
+			Dimensions:       tsDimensions,
+			Time:             aws.String(i.t),
+			TimeUnit:         timeUnit,
 		})
 	}
 
 	result := &timestreamwrite.WriteRecordsInput{
-		DatabaseName: aws.String(tsDbName),
-		TableName:    aws.String(i.tableName),
-		Records:      tsRecords,
-		CommonAttributes: &types.Record{
-			Dimensions: tsDimensions,
-			Time:       aws.String(i.t),
-			TimeUnit:   types.TimeUnitSeconds,
-		},
+		DatabaseName:     aws.String(tsDbName),
+		TableName:        aws.String(i.tableName),
+		Records:          tsRecords,
+		CommonAttributes: &types.Record{},
 	}
 
 	return result
 }
+
+func buildRecords(inputs []SimpleInput) []types.Record {
+	var tsRecords []types.Record
+
+	for _, inp := range inputs {
+		tsRecords = append(tsRecords, buildRecord(inp)...)
+	}
+
+	return tsRecords
+}
+
+func buildRecord(input SimpleInput) []types.Record {
+	var tsRecords []types.Record
+
+	var tsDimensions []types.Dimension
+
+	for k, v := range input.dimensions {
+		tsDimensions = append(tsDimensions, types.Dimension{
+			Name:  aws.String(k),
+			Value: aws.String(v),
+		})
+	}
+
+	for k, v := range input.measureValues {
+		tsRecords = append(tsRecords, types.Record{
+			MeasureName:      aws.String(k),
+			MeasureValue:     aws.String(v),
+			MeasureValueType: types.MeasureValueTypeDouble,
+			Dimensions:       tsDimensions,
+			Time:             aws.String(input.t),
+			TimeUnit:         timeUnit,
+		})
+	}
+
+	return tsRecords
+}
